package sample;
import static org.junit.Assert.*;
import static org.hamcrest.CoreMatchers.*;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;

import org.junit.Test;

import sample.entity.User;

public class JpaHibernateTest {
	private static final String PERSISTENCE_UNIT_NAME = "jpa-sample1";
	
	/**
	 * VKǉ(Insert)
	 */
	@Test
	public void insert() {
		// i
		// ------------------------------
		EntityManagerFactory factory = Persistence.createEntityManagerFactory(PERSISTENCE_UNIT_NAME);
		EntityManager entityManager = factory.createEntityManager();
		
		// f[^̒ǉ
		// ************************************
		
		// EntityBeannew 
		// CtTCN:new
		// ------------------------------
		User user = new User();
		user.setId("1");
		user.setName("Insert");
		user.setAge(10);
	
		// Insert
		// CtTCN:managed
		// ------------------------------
		entityManager.getTransaction().begin();
		entityManager.persist(user);
		entityManager.getTransaction().commit();
		
		// ǗĂEntityBeanNA
		// CtTCN:detached
		// ------------------------------		
		entityManager.clear();
	
		
		// mF
		// ************************************
		User actual = entityManager.find(User.class, "1");
		assertThat(actual.getId(), is("1"));
		assertThat(actual.getName(), is("Insert"));
		assertThat(actual.getAge(), is(10));
	}

	/**
	 * XV(Update)
	 */
	@Test
	public void update() {
		// i
		// ------------------------------
		EntityManagerFactory factory = Persistence.createEntityManagerFactory(PERSISTENCE_UNIT_NAME);
		EntityManager entityManager = factory.createEntityManager();
		
		// f[^̒ǉ
		// ************************************
		
		// EntityBeannew 
		// CtTCN:new
		// ------------------------------
		User user = new User();
		user.setId("1");
		user.setName("Insert");
		user.setAge(10);
	
		// Insert
		// CtTCN:managed
		// ------------------------------
		entityManager.getTransaction().begin();
		entityManager.persist(user);
		entityManager.getTransaction().commit();
		
		// ǗĂEntityBeanNA
		// CtTCN:detached
		// ------------------------------		
		entityManager.clear();
	
		
		// f[^̍XV
		// ************************************
		
		// Select
		// CtTCN:managed
		// ------------------------------				
		User user2 = entityManager.find(User.class, "1");
		user2.setName("Update");
		
		// Update
		// CtTCN:managed
		// ------------------------------		
		entityManager.getTransaction().begin();
		entityManager.merge(user2);
		entityManager.getTransaction().commit();
	
		// ǗĂEntityBeanNA
		// CtTCN:detached
		// ------------------------------		
		entityManager.clear();
		
		
		// mF
		// ************************************
		User actual = entityManager.find(User.class, "1");
		assertThat(actual.getName(), is("Update"));
	}

	/**
	 * 폜(Delete)
	 */
	@Test
	public void delete() {
		// i
		// ------------------------------
		EntityManagerFactory factory = Persistence.createEntityManagerFactory(PERSISTENCE_UNIT_NAME);
		EntityManager entityManager = factory.createEntityManager();
		
		// f[^̒ǉ
		// ************************************
		
		// EntityBeannew 
		// CtTCN:new
		// ------------------------------
		User user = new User();
		user.setId("1");
		user.setName("Insert");
		user.setAge(10);

		// Insert
		// CtTCN:managed
		// ------------------------------
		entityManager.getTransaction().begin();
		entityManager.persist(user);
		entityManager.getTransaction().commit();
		
		// ǗĂEntityBeanNA
		// CtTCN:detached
		// ------------------------------		
		entityManager.clear();

		
		// f[^̍폜
		// ************************************
		
		// Select
		// CtTCN:managed
		// ------------------------------				
		User user2 = entityManager.find(User.class, "1");
		
		// Delete
		// CtTCN:removed
		// ------------------------------		
		entityManager.getTransaction().begin();
		entityManager.remove(user2);
		entityManager.getTransaction().commit();

		// ǗĂEntityBeanNA
		// CtTCN:detached
		// ------------------------------		
		entityManager.clear();
		
		
		// mF
		// ************************************
		User actual = entityManager.find(User.class, "1");
		assertThat(actual, nullValue());
	}

	/**
	 * L[ɂQ(Select)
	 */
	@Test
	public void selectByPk() {
		// i
		// ------------------------------
		EntityManagerFactory factory = Persistence.createEntityManagerFactory(PERSISTENCE_UNIT_NAME);
		EntityManager entityManager = factory.createEntityManager();
		
		// f[^̒ǉ
		// ************************************
		
		// EntityBeannew 
		// CtTCN:new
		// ------------------------------
		User user = new User();
		user.setId("1");
		user.setName("Insert");
		user.setAge(10);
	
		// Insert
		// CtTCN:managed
		// ------------------------------
		entityManager.getTransaction().begin();
		entityManager.persist(user);
		entityManager.getTransaction().commit();
		
		// ǗĂEntityBeanNA
		// CtTCN:detached
		// ------------------------------		
		entityManager.clear();
	
		
		// Select
		// CtTCN:managed
		// ------------------------------
		User actual = entityManager.find(User.class, "1");
		
		// mF
		// ************************************
		assertThat(actual.getId(), is("1"));
		assertThat(actual.getName(), is("Insert"));
		assertThat(actual.getAge(), is(10));
	}
}
